import path from 'path';
import { URL } from 'url';
import Handlebars from 'handlebars';
export function registerBuiltInHelpers(config) {
    Handlebars.registerHelper('url', (pathname) => {
        if (typeof pathname === 'string') {
            return new URL(pathname, config.baseUrl);
        }
        return new URL('', config.baseUrl);
    });
    Handlebars.registerHelper('asset', (pathname) => {
        if (typeof pathname === 'string') {
            return new URL(path.join(config.assets, pathname), config.baseUrl);
        }
        return new URL(config.assets, config.baseUrl).pathname;
    });
    Handlebars.registerHelper('formatDate', (date, options) => {
        const dateToFormat = date === 'now' ? new Date() : new Date(date);
        const args = (options?.hash ?? {});
        return new Intl.DateTimeFormat(args.lang ?? 'en', args).format(dateToFormat);
    });
    Handlebars.registerHelper('formatNumber', (num, options) => {
        const args = (options?.hash ?? {});
        const numberToFormat = parseFloat(String(num));
        return new Intl.NumberFormat(args.lang ?? 'en', args).format(numberToFormat);
    });
}
