import fs from 'fs/promises';
import path from 'path';
import cpy from 'cpy';
import { WriteError } from './utilities/errors.js';
export async function copyAssets(config) {
    if (config.assets) {
        const from = `${path.join(config.source, config.assets)}/**/*`;
        const to = path.join(config.destination, config.assets);
        try {
            await fs.mkdir(to, { recursive: true });
            const copiedFiles = await cpy(from, to);
            return copiedFiles;
        }
        catch (err) {
            const message = `Doxicity wasn't able to copy assets from "${from}" to "${to}".\n\n` +
                `Please verify that the target directories have the correct permissions and try again.`;
            throw new WriteError(message);
        }
    }
    return [];
}
